Finite Elements Method for Room Acoustics
	Package python for acoustical simulations using finite elements method.

Internship project for a Master 2 in Acoustical Engineering at ENSTA-Paris (École Nationale Supérieure de
Techniques Avancées).

